@@ -397,12 +397,26 @@ class VirtualService(HttpClient, KempBaseObjectModel):
             response = self._get("/addvs", self._get_base_parameters())
         else:
             response = self._get("/modvs", self.to_api_dict())
-        return send_response(response)
+        if is_successful(response):
+            vs_data = get_data(response)
+            self.populate_virtual_service_attributes(vs_data)
+        else:
+            raise KempTechApiException(get_error_msg(response))
 
     def delete(self):
         response = self._get("/delvs", self._get_base_parameters())
         return send_response(response)
 
+    def populate_virtual_service_attributes(self, service):
+        """Populate VirtualService instance with standard defaults"""
+        self.status = service.get('Status', None)
+        self.index = service.get('Index', None)
+        self.enable = service.get('Enable', None)
+        self.forcel7 = service.get('ForceL7', None)
+        self.vstype = service.get('VStype', None)
+        self.schedule = service.get('Schedule', None)
+        self.nickname = service.get('NickName', None)
+
     def create_real_server(self, ip, port=80):
         """RealServer factory with pre-configured LoadMaster connection."""
         loadmaster_virt_service_info = self._get_base_parameters()
